@@ -59,10 +59,10 @@ typedef unsigned char     uint8_t;	/* 8-bit int */
   typedef unsigned  short  uint16_t;	/* 16-bit int */
   typedef   signed  int   int32_t;	/* 32-bit int */
   typedef unsigned  int  uint32_t;	/* 32-bit int */
-  typedef   signed  long   int64_t;	/* 64-bit int */
-  typedef unsigned  long  uint64_t;	/* 64-bit int */
-  typedef   signed long  intptr_t;
-  typedef unsigned long uintptr_t;
+  typedef   signed  long long   int64_t;	/* 64-bit int */
+  typedef unsigned  long long  uint64_t;	/* 64-bit int */
+  typedef   signed int  intptr_t;
+  typedef unsigned int uintptr_t;
 #  endif
 #endif
 
